%define _libdir64 %{_prefix}/lib64

Summary:	C++ user interface toolkit
Name:		fltk
Version:	1.1.10
Release:	1

# see COPYING (or http://www.fltk.org/COPYING.php ) for exceptions details
License:	LGPLv2+ with exceptions	
Group:		System Environment/Libraries
URL:		http://www.fltk.org/
Source0:	http://ftp.easysw.com/pub/fltk/%{version}/%{name}-%{version}-source.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root

BuildRequires: coreutils

BuildRequires: fontconfig-devel >= 2.8.0-1
BuildRequires: libjpeg-devel >= 6b-7
BuildRequires: libpng-devel >= 1.2.46-1
BuildRequires: zlib-devel >= 1.2.3-3

Requires: fontconfig >= 2.8.0-1
Requires: libjpeg >= 6b-7
Requires: libpng >= 1.2.46-1
Requires: zlib >= 1.2.3-3

%description
FLTK (pronounced "fulltick") is a cross-platform C++ GUI toolkit.
It provides modern GUI functionality without the bloat, and supports
3D graphics via OpenGL and its built-in GLUT emulation.

The library is available as 32-bit and 64-bit.


%package devel
Summary: Development files for %{name}
Group:   System Environment/Libraries
Requires: %{name} = %{version}-%{release}

%description devel
%{summary}.

If you are compiling a 32-bit program, no special compiler options are
needed.

If you are compiling a 64-bit program, you have to compile and link your
application with "xlc_r -q64" or "gcc -maix64".


%package fluid
Summary: Fast Light User Interface Designer
Group:   System Environment/Libraries
Requires: %{name} = %{version}-%{release}
Requires: %{name}-devel = %{version}-%{release}

%description fluid
%{summary}, an interactive GUI designer for %{name}. 


%package games
Summary: Fast Light Demo Games
Group:   System Environment/Libraries
Requires: %{name} = %{version}-%{release}

%description games
The demo games included in FLTK.


%prep
%setup -q
mkdir ../32bit
mv * ../32bit
mv ../32bit .
mkdir 64bit
cd 32bit && tar cf - . | (cd ../64bit ; tar xpf -)


%build
export CC="xlc_r"
export CXX="xlC_r"

################################# 64 bit ##################################

cd 64bit
# first build the 64-bit version
export OBJECT_MODE=64
export LDFLAGS="-L/opt/freeware/lib64 -L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib64:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir64} \
    --mandir=%{_mandir} \
    --enable-x11 \
    --enable-gl \
    --disable-shared \
    --enable-threads \
    --enable-largefile \
    --disable-localjpeg \
    --disable-localzlib \
    --disable-localpng \
    --disable-xinerama \
    --enable-xft \
    --disable-xdbe \
    --with-links \
    --with-x
cd src
make %{?_smp_mflags}
cd ../lib

#
# convert all static libraries into shared ones
#

rpath="-Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib"

build_shlib()
{
  i=$1

  CreateExportList -X64 ${i}.exp ${i}.a
  ${CXX} -qmkshrobj ${i}.a -o ${i}.so.${sorev} -bE:${i}.exp ${rpath} ${deplibs}
  rm -f ${i}.exp
  rm -f ${i}.a
  # now create the AIX-style shared library
  /usr/bin/ar -X64 -rv ${i}.a ${i}.so.${sorev}
}

deplibs="-lXft -lX11 -lfontconfig -lm"
sorev=1
build_shlib libfltk

deplibs="-L. -lfltk"
sorev=1
build_shlib libfltk_forms

deplibs="-L. -lfltk -lGL -lXft -lX11 -lfontconfig"
sorev=1
build_shlib libfltk_gl

deplibs="-L. -lfltk -lpng -ljpeg"
sorev=1
build_shlib libfltk_images

################################# 32 bit ##################################

cd ../../32bit
# now build the 32-bit version
export OBJECT_MODE=32
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"
./configure \
    --prefix=%{_prefix} \
    --mandir=%{_mandir} \
    --enable-x11 \
    --enable-gl \
    --disable-shared \
    --enable-threads \
    --enable-largefile \
    --disable-localjpeg \
    --disable-localzlib \
    --disable-localpng \
    --disable-xinerama \
    --enable-xft \
    --disable-xdbe \
    --with-links \
    --with-x
cd src
make %{?_smp_mflags}
cd ../lib

#
# convert all static libraries into shared ones
#

rpath="-Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib"

build_shlib()
{
  i=$1

  CreateExportList -X32 ${i}.exp ${i}.a
  ${CXX} -qmkshrobj ${i}.a -o ${i}.so.${sorev} -bE:${i}.exp ${rpath} ${deplibs}
  rm -f ${i}.exp
  rm -f ${i}.a
  # now create the AIX-style shared library
  /usr/bin/ar -X32 -rv ${i}.a ${i}.so.${sorev}
}

deplibs="-lXft -lX11 -lfontconfig -lm"
sorev=1
build_shlib libfltk

deplibs="-L. -lfltk"
sorev=1
build_shlib libfltk_forms

deplibs="-L. -lfltk -lGL -lXft -lX11 -lfontconfig"
sorev=1
build_shlib libfltk_gl

deplibs="-L. -lfltk -lpng -ljpeg"
sorev=1
build_shlib libfltk_images

cd ../fluid
# required to get the proper shared library shared path into the binaries
make LINKFLTK="-L/opt/freeware/lib -lfltk" LINKFLTKFORMS="-L/opt/freeware/lib -lfltk_forms" LINKFLTKIMG="-L/opt/freeware/lib -lfltk_images -lfltk -lpng -lz -ljpeg" LDLIBS="-lpthreads -lm -lX11"

cd ..
# required to get the proper shared library shared path into the binaries
make LINKFLTK="-L/opt/freeware/lib -lfltk" LINKFLTKFORMS="-L/opt/freeware/lib -lfltk_forms -lfltk" LINKFLTKIMG="-L/opt/freeware/lib -lfltk_images -lfltk -lpng -lz -ljpeg" LDLIBS="-lpthreads -lm -lX11"


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

cd 64bit
export OBJECT_MODE=64
make install install-desktop DESTDIR=${RPM_BUILD_ROOT} INSTALL=/opt/freeware/bin/install

cd ../32bit
export OBJECT_MODE=32
make install install-desktop DESTDIR=${RPM_BUILD_ROOT} INSTALL=/opt/freeware/bin/install

/usr/bin/strip -X32_64 ${RPM_BUILD_ROOT}%{_bindir}/* || :

# errant man pages
rm -rf ${RPM_BUILD_ROOT}%{_mandir}/cat*

(
  cd ${RPM_BUILD_ROOT}%{_libdir64}
  for f in *.a ; do
    /usr/bin/ar -X64 -x ${f}
  done

  cd ${RPM_BUILD_ROOT}%{_libdir}
  for f in *.a ; do
    /usr/bin/ar -X32 -x ${f}
  done
)

# add the 64-bit shared objects to the shared libraries containing already the
# 32-bit shared objects
for i in "" _forms _gl _images ; do
  /usr/bin/ar -X64 -q ${RPM_BUILD_ROOT}%{_libdir}/lib%{name}${i}.a ${RPM_BUILD_ROOT}%{_libdir64}/lib%{name}${i}.so*
done

# move icons etc. into the right position
cd ${RPM_BUILD_ROOT}/usr/share
mv applications icons ${RPM_BUILD_ROOT}%{_datadir}

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib lib64
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system,-)
%doc 32bit/ANNOUNCEMENT 32bit/CHANGES 32bit/COPYING 32bit/CREDITS 32bit/README
%{_libdir}/*.a
%{_libdir}/*.so*
%{_libdir64}/*.so*
%{_datadir}/doc/%{name}
/usr/lib/*.a
/usr/lib/*.so*
/usr/lib64/*.so*


%files devel
%defattr(-,root,system,-)
%{_bindir}/fltk-config*
%{_includedir}/*
%{_mandir}/man1/fltk-config.1*
%{_mandir}/man3/fltk.3*
/usr/bin/fltk-config*
/usr/include/*


%files fluid
%defattr(-,root,system,-)
%{_bindir}/fluid
%{_mandir}/man1/fluid.1
%{_datadir}/applications/fluid.desktop
%{_datadir}/icons/hicolor/*/*/*
/usr/bin/fluid


%files games
%defattr(-,root,system,-)
%{_bindir}/blocks
%{_bindir}/checkers
%{_bindir}/sudoku
%{_mandir}/man6/*
/usr/bin/blocks
/usr/bin/checkers
/usr/bin/sudoku


%changelog
* Tue Nov 08 2011 Michael Perzl <michael@perzl.org> - 1.1.10-1
- first version for AIX V5.1 and higher
